Module list

Module list 

Virtualized list widget for efficient scrolling.

The List widget only renders items that are visible in the viewport, enabling smooth scrolling of thousands of items.

Structs

List
Virtualized list widget.
ListItem
List item data for virtualization.
ListItemClicked
Message emitted when a list item is clicked.
ListItemSelected
Message emitted when a list item is selected.
ListScrolled
Message emitted when list is scrolled.

Enums

ListDirection
Direction of the list.
SelectionMode
Selection mode for list items.

Type Aliases

RenderItemFn
Type alias for the render item callback.