Virtualized list widget for efficient scrolling.
The List widget only renders items that are visible in the viewport, enabling smooth scrolling of thousands of items.
Structs
- List
- Virtualized list widget.
- List
Item - List item data for virtualization.
- List
Item Clicked - Message emitted when a list item is clicked.
- List
Item Selected - Message emitted when a list item is selected.
- List
Scrolled - Message emitted when list is scrolled.
Enums
- List
Direction - Direction of the list.
- Selection
Mode - Selection mode for list items.
Type Aliases
- Render
Item Fn - Type alias for the render item callback.